@@ -1,6 +1,6 @@
 # vim: ft=python fileencoding=utf-8 sts=4 sw=4 et:
 
-# Copyright 2014-2018 Florian Bruhin (The Compiler) <mail@qutebrowser.org>
+# Copyright 2014-2019 Florian Bruhin (The Compiler) <mail@qutebrowser.org>
 #
 # This file is part of qutebrowser.
 #
@@ -28,10 +28,11 @@ from PyQt5.QtCore import (pyqtSlot, QRect, QPoint, QTimer, Qt,
                           QCoreApplication, QEventLoop)
 from PyQt5.QtWidgets import QWidget, QVBoxLayout, QApplication, QSizePolicy
 
-from qutebrowser.commands import runners, cmdutils
+from qutebrowser.commands import runners
+from qutebrowser.api import cmdutils
 from qutebrowser.config import config, configfiles
 from qutebrowser.utils import (message, log, usertypes, qtutils, objreg, utils,
-                               jinja)
+                               jinja, debug)
 from qutebrowser.mainwindow import messageview, prompt
 from qutebrowser.completion import completionwidget, completer
 from qutebrowser.keyinput import modeman
@@ -136,6 +137,7 @@ class MainWindow(QWidget):
     Attributes:
         status: The StatusBar widget.
         tabbed_browser: The TabbedBrowser widget.
+        state_before_fullscreen: window state before activation of fullscreen.
         _downloadview: The DownloadView widget.
         _vbox: The main QVBoxLayout.
         _commandrunner: The main CommandRunner instance.
@@ -143,6 +145,18 @@ class MainWindow(QWidget):
         _private: Whether the window is in private browsing mode.
     """
 
+    # Application wide stylesheets
+    STYLESHEET = """
+        HintLabel {
+            background-color: {{ conf.colors.hints.bg }};
+            color: {{ conf.colors.hints.fg }};
+            font: {{ conf.fonts.hints }};
+            border: {{ conf.hints.border }};
+            padding-left: 3px;
+            padding-right: 3px;
+        }
+    """
+
     def __init__(self, *, private, geometry=None, parent=None):
         """Create a new main window.
 
@@ -237,6 +251,9 @@ class MainWindow(QWidget):
         objreg.get("app").new_window.emit(self)
         self._set_decoration(config.val.window.hide_decoration)
 
+        self.state_before_fullscreen = self.windowState()
+        config.set_register_stylesheet(self)
+
     def _init_geometry(self, geometry):
         """Initialize the window geometry or load it from disk."""
         if geometry is not None:
@@ -267,7 +284,7 @@ class MainWindow(QWidget):
             left = padding
         else:
             width = min(size_hint.width(), self.width() - 2 * padding)
-            left = (self.width() - width) / 2 if centered else 0
+            left = (self.width() - width) // 2 if centered else 0
 
         height_padding = 20
         status_position = config.val.statusbar.position
@@ -470,8 +487,7 @@ class MainWindow(QWidget):
         # statusbar
         self.tabbed_browser.current_tab_changed.connect(status.on_tab_changed)
 
-        self.tabbed_browser.cur_progress.connect(status.prog.setValue)
-        self.tabbed_browser.cur_load_finished.connect(status.prog.hide)
+        self.tabbed_browser.cur_progress.connect(status.prog.on_load_progress)
         self.tabbed_browser.cur_load_started.connect(
             status.prog.on_load_started)
 
@@ -516,9 +532,13 @@ class MainWindow(QWidget):
     def _on_fullscreen_requested(self, on):
         if not config.val.content.windowed_fullscreen:
             if on:
-                self.setWindowState(self.windowState() | Qt.WindowFullScreen)
+                self.state_before_fullscreen = self.windowState()
+                self.setWindowState(
+                    Qt.WindowFullScreen | self.state_before_fullscreen)
             elif self.isFullScreen():
-                self.setWindowState(self.windowState() & ~Qt.WindowFullScreen)
+                self.setWindowState(self.state_before_fullscreen)
+        log.misc.debug('on: {}, state before fullscreen: {}'.format(
+            on, debug.qflags_key(Qt, self.state_before_fullscreen)))
 
     @cmdutils.register(instance='main-window', scope='window')
     @pyqtSlot()
@@ -576,8 +596,7 @@ class MainWindow(QWidget):
         quit_texts = []
         # Ask if multiple-tabs are open
         if 'multiple-tabs' in config.val.confirm_quit and tab_count > 1:
-            quit_texts.append("{} {} open.".format(
-                tab_count, "tab is" if tab_count == 1 else "tabs are"))
+            quit_texts.append("{} tabs are open.".format(tab_count))
         # Ask if multiple downloads running
         if 'downloads' in config.val.confirm_quit and download_count > 0:
             quit_texts.append("{} {} running.".format(
